@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2017-2022 by the Free Software Foundation, Inc.
+# Copyright (C) 2017-2023 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -219,5 +219,9 @@ def rebuild_email_cache_votes(email_id):
 
 
 def _rebuild_email_cache_votes(email_id):
-    email = Email.objects.get(id=email_id)
+    try:
+        email = Email.objects.get(id=email_id)
+    except Email.DoesNotExist:
+        log.warning(f'Email with id {email_id} does not exist.')
+        return
     email.cached_values["votes"].rebuild()
