@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2014-2022 by the Free Software Foundation, Inc.
+# Copyright (C) 2014-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -24,6 +24,7 @@
 import datetime
 import json
 import re
+from datetime import timezone as tz
 
 from django.conf import settings
 from django.contrib import messages
@@ -33,7 +34,6 @@ from django.http import Http404, HttpResponse
 from django.shortcuts import get_object_or_404, redirect, render
 from django.template import loader
 from django.urls import reverse
-from django.utils.timezone import utc
 from django.utils.translation import gettext as _
 from django.views.decorators.http import require_POST
 
@@ -159,8 +159,15 @@ def thread_index(request, mlist_fqdn, threadid, month=None, year=None):
     # Last view
     last_view = None
     if request.user.is_authenticated:
-        last_view_obj, created = LastView.objects.get_or_create(
-                thread=thread, user=request.user)
+        try:
+            last_view_obj, created = LastView.objects.get_or_create(
+                    thread=thread, user=request.user)
+        except LastView.MultipleObjectsReturned:
+            last_view_duplicate, last_view_obj = LastView.objects.filter(
+                    thread=thread,
+                    user=request.user).order_by("view_date").all()
+            last_view_duplicate.delete()
+            created = False
         if not created:
             last_view = last_view_obj.view_date
             last_view_obj.save()  # update timestamp
@@ -212,6 +219,7 @@ def thread_index(request, mlist_fqdn, threadid, month=None, year=None):
         'num_comments': thread.emails_count - 1,
         'last_view': last_view,
         'unread_count': unread_count,
+        'user_is_owner': mlist.is_owner(request.user),
         # XX(abraj): Commenting it out, since we don't need this. We aren't
         # really using. At some point we can remove this but I am commenting.
         #
@@ -243,7 +251,7 @@ def replies(request, mlist_fqdn, threadid):
     last_view = request.GET.get("last_view")
     if last_view:
         try:
-            last_view = datetime.datetime.fromtimestamp(int(last_view), utc)
+            last_view = datetime.datetime.fromtimestamp(int(last_view), tz.utc)
         except ValueError:
             last_view = None
     context = {
@@ -387,10 +395,13 @@ def set_category(request, mlist_fqdn, threadid):
 
 @check_mlist_private
 def reattach(request, mlist_fqdn, threadid):
-    if not request.user.is_staff and not request.user.is_superuser:
-        return HttpResponse('You must be a staff member to reattach a thread',
-                            content_type="text/plain", status=403)
     mlist = request.mlist
+    if not (request.user.is_staff or
+            request.user.is_superuser or
+            mlist.is_owner(request.user)):
+        return HttpResponse(
+            'You must be a staff member or list owner to reattach a thread',
+            content_type="text/plain", status=403)
     thread = get_object_or_404(Thread, mailinglist=mlist, thread_id=threadid)
     context = {
         'mlist': mlist,
